@@ -4,9 +4,12 @@ import (
 	"fmt"
 	"strconv"
 	"strings"
+	"time"
 
 	"github.com/gookit/color"
+	"github.com/jandedobbeleer/oh-my-posh/src/cache"
 	"github.com/jandedobbeleer/oh-my-posh/src/runtime"
+	"github.com/jandedobbeleer/oh-my-posh/src/template"
 )
 
 var TrueColor = true
@@ -25,6 +28,20 @@ type Set struct {
 	Foreground Ansi `json:"foreground" toml:"foreground"`
 }
 
+func (c *Set) String() string {
+	return fmt.Sprintf("%s|%s", c.Foreground, c.Background)
+}
+
+func (c *Set) ParseString(colors string) {
+	parts := strings.Split(colors, "|")
+	if len(parts) != 2 {
+		return
+	}
+
+	c.Foreground = Ansi(parts[0])
+	c.Background = Ansi(parts[1])
+}
+
 type History []*Set
 
 func (c *History) Len() int {
@@ -103,6 +120,29 @@ func (c Ansi) ToForeground() Ansi {
 	return c
 }
 
+func (c Ansi) ResolveTemplate(env runtime.Environment) Ansi {
+	if c.IsEmpty() {
+		return c
+	}
+
+	if c.IsTransparent() {
+		return emptyColor
+	}
+
+	tmpl := &template.Text{
+		Template: string(c),
+		Context:  nil,
+		Env:      env,
+	}
+
+	text, err := tmpl.Render()
+	if err != nil {
+		return Transparent
+	}
+
+	return Ansi(text)
+}
+
 func (c Ansi) String() string {
 	return string(c)
 }
@@ -120,6 +160,42 @@ func MakeColors(palette Palette, cacheEnabled bool, accentColor Ansi, env runtim
 	return
 }
 
+func (d *Defaults) SetAccentColor(env runtime.Environment, defaultColor Ansi) {
+	defer env.Trace(time.Now())
+
+	// get accent color from session cache first
+	if accent, OK := env.Session().Get("accent_color"); OK {
+		accentColors := &Set{}
+		accentColors.ParseString(accent)
+		d.accent = accentColors
+		return
+	}
+
+	rgb, err := GetAccentColor(env)
+	if err != nil {
+		d.accent = &Set{
+			Foreground: d.ToAnsi(defaultColor, false),
+			Background: d.ToAnsi(defaultColor, true),
+		}
+
+		return
+	}
+
+	if len(defaultColor) == 0 {
+		return
+	}
+
+	foreground := color.RGB(rgb.R, rgb.G, rgb.B, false)
+	background := color.RGB(rgb.R, rgb.G, rgb.B, true)
+
+	d.accent = &Set{
+		Foreground: Ansi(foreground.String()),
+		Background: Ansi(background.String()),
+	}
+
+	env.Session().Set("accent_color", d.accent.String(), cache.INFINITE)
+}
+
 type RGB struct {
 	R, G, B uint8
 }
