@@ -2,6 +2,8 @@ package prompt
 
 import (
 	"github.com/jandedobbeleer/oh-my-posh/src/config"
+	"github.com/jandedobbeleer/oh-my-posh/src/runtime"
+	"github.com/jandedobbeleer/oh-my-posh/src/shell"
 )
 
 func (e *Engine) RPrompt() string {
@@ -29,5 +31,10 @@ func (e *Engine) RPrompt() string {
 	text, length := e.renderBlockSegments(rprompt)
 	e.rpromptLength = length
 
+	if e.Env.Shell() == shell.ELVISH && e.Env.GOOS() != runtime.WINDOWS {
+		// Workaround to align with a right-aligned block on non-Windows systems.
+		text += " "
+	}
+
 	return text
 }
